@@ -2,7 +2,7 @@ package Backblaze::B2V2Client;
 # API client library for V2 of the API to Backblaze B2 object storage
 # Allows for creating/deleting buckets, listing files in buckets, and uploading/downloading files
 
-$Backblaze::B2V2Client::VERSION = '1.4';
+$Backblaze::B2V2Client::VERSION = '1.5';
 
 # our dependencies:
 use Cpanel::JSON::XS;
@@ -387,23 +387,34 @@ sub b2_get_file_info {
 sub b2_bucket_maker {
 	my $self = shift;
 
-	my ($bucket_name) = @_;
+	my ($bucket_name, $disable_encryption) = @_;
 
 	# can't proceed without the bucket_name
 	if (!$bucket_name) {
 		$self->error_tracker('The bucket_name must be provided for b2_bucket_maker().');
 		return;
 	}
+	
+	# prepare the basics for our request
+	my $post_params = {
+		'accountId' => $self->{account_id},
+		'bucketName' => $bucket_name,
+		'bucketType' => 'allPrivate',
+	};
+
+	# unless instructed otherwise, we should encrypt the files in this bucket
+	unless ($disable_encryption) {
+		$$post_params{defaultServerSideEncryption} = {
+			'mode' => 'SSE-B2',
+			'algorithm' => 'AES256',
+		};
+	}
 
 	# create the bucket...
 	$self->b2_talker(
 		'url' => $self->{api_url}.'/b2api/v2/b2_create_bucket',
 		'authorization' => $self->{account_authorization_token},
-		'post_params' => {
-			'accountId' => $self->{account_id},
-			'bucketName' => $bucket_name,
-			'bucketType' => 'allPrivate',
-		},
+		'post_params' => $post_params,
 	);
 
 	if ($self->{current_status} eq 'OK') { # if successful...
@@ -827,9 +838,9 @@ Key again, so copy it immediately.
 Please store the Application Key pair in a secure way, preferably encrypted
 when not in use by your software.
 
-=head2 New: b2_client Command Line Utility
+=head2 b2_client Command Line Utility
 
-Backblaze::B2V2Client now includes the 'b2_client' command line utility to
+Backblaze::B2V2Client includes the 'b2_client' command line utility to
 easily download or upload files from B2.  Please execute 'b2_client help'
 for more details, and here are a few examples:
 
@@ -986,9 +997,9 @@ Example:
 =head2 b2_bucket_maker
 
 Creates a new bucket in your B2 account, given the name for the new
-bucket.  The bucket type will be set to 'allPrivate'.
+bucket.  The bucket type will be set to 'allPrivate',
 
-Will retrieve the new bucket's ID into:
+Will place the new bucket's ID into:
 
 	$b2client->{buckets}{$bucket_name}{bucket_id}
 
@@ -998,6 +1009,16 @@ Example:
 
 	$b2client->b2_bucket_maker('NewBucketName');
 
+By default the new bucket will be set to use the 'Server-Side 
+Encryption with Backblaze-Managed Keys (SSE-B2)' option 
+described here: https://www.backblaze.com/b2/docs/server_side_encryption.html
+You can send a second param to disable that (not recommended):
+
+	$b2client->b2_bucket_maker('UnEncryptedBucketName', 1);
+	
+Also, if your app key does not have the 'writeBucketEncryption' then 
+encryption will be disabled.
+
 =head2 b2_delete_bucket
 
 Deletes a bucket from your B2 account, provided that it is empty.
